import React, { PureComponent } from 'react';
import Ogma from 'ogma';


export default class OgmaComponent extends PureComponent {

    componentDidUpdate(prevProps) {
        // add a node
        if (prevProps.data.nodes.length < this.props.data.nodes.length) {
            // update the data in ogma
            return this.ogmaRef.addGraph(this.props.data)
                .then(() =>
                    this.runLayout()
                );
        }

        if(prevProps.layout !== this.props.layout){
            return this.runLayout();
        }
    }

    runLayout(){
        const options = {locate: true};
        if(this.props.layout === 'hierarchical'){
          // set node with ID = 1 as root of the hierarchy. Shown as an example to customise options per-layout
          // Alternatively the layout can work out the root automatically, or we could use user's selection.
          options.roots = [1];
        }
        return this.ogmaRef.layouts[this.props.layout](options);
      }

    componentDidMount() {
        // create the Ogma instance
        this.ogmaRef = new Ogma({
            container: 'ogma-react',
            options: {
                backgroundColor: 'rgb(240, 240, 240)'
            },
            graph: this.props.data
        });

        this.ogmaRef.layouts.force({ locate: true });

        this.bindEvents();
        
    }

    // when passed a on* event as React prop it checks it and bind it to the ogma instance
    bindEvents() {
    // See the Ogma.events namespace: https://doc.linkurio.us/ogma/latest/api.html#Ogma-events
        Object.keys(this.props).forEach(prop => {
            if (/^on/.test(prop) && prop in this.ogmaRef.events) {
                this.ogmaRef.events[prop](this.props[prop]);
            }
        });
    }

    componentWillUnmount() {
        this.ogmaRef.destroy();
    }

    render() {
        return <div id='ogma-react' style={{width: 800, height: 600}}> </div>
    }
}